@@ -86,10 +86,8 @@
 #include <config-kstars.h>
 
 #ifdef HAVE_INDI_H
-#include "ekos/ekosmanager.h"
 #include "indi/telescopewizardprocess.h"
 #include "indi/opsindi.h"
-#include "ekos/opsekos.h"
 #include "indi/drivermanager.h"
 #include "indi/guimanager.h"
 #endif
@@ -104,7 +102,8 @@
 #ifdef HAVE_CFITSIO_H
 #include "fitsviewer/fitsviewer.h"
 #ifdef HAVE_INDI_H
-//#include "ekos/ekos.h"
+#include "ekos/ekosmanager.h"
+#include "ekos/opsekos.h"
 #endif
 #endif
 
@@ -444,10 +443,13 @@ void KStars::slotViewOps() {
     opsindi = new OpsINDI (this);
     dialog->addPage(opsindi, i18n("INDI"), "kstars");
 
+    #ifdef HAVE_CFITSIO_H
     opsekos = new OpsEkos(this);
     dialog->addPage(opsekos, i18n("Ekos"), "kstars");
     #endif
 
+    #endif
+
 #ifdef HAVE_XPLANET
     opsxplanet = new OpsXplanet( this );
     dialog->addPage(opsxplanet, i18n("Xplanet"), "kstars_xplanet");
