@@ -15,54 +15,53 @@
  *                                                                         *
  ***************************************************************************/
 
-#pragma once
+#ifndef DEEPSKYCOMPONENT_H
+#define DEEPSKYCOMPONENT_H
 
+#include "typedef.h"
+
+#include <QObject>
 #include "skycomponent.h"
 #include "skylabel.h"
 
-class QPointF;
+#define NNGCFILES 14
 
-#ifdef KSTARS_LITE
-class DeepSkyItem;
-#endif
-class DeepSkyObject;
-class KSNumbers;
+class QColor;
 class SkyMap;
-class SkyMesh;
+class KSNumbers;
+class DeepSkyObject;
 class SkyPoint;
+class SkyMesh;
+class SkyLabeler;
 
 // NOTE: Although the following symbol has nothing to do with line
 // number in any file, we use this name to keep consistency in naming
 // conventions with StarComponent
 #define MAX_LINENUMBER_MAG 90
 
-typedef QVector<DeepSkyObject *> DeepSkyList;
-typedef QHash<int, DeepSkyList *> DeepSkyIndex;
+typedef QVector< DeepSkyObject*>    DeepSkyList;
+typedef QHash< int, DeepSkyList*>   DeepSkyIndex;
 
 /**
  * @class DeepSkyComponent
- * Represents the deep sky objects separated by catalogs.
+ * Represents the deep sky objects separated by catalogs. 
  * Custom Catalogs are a standalone component.
- * @note this Component is similar to ListComponent, but
+ * @note this Component is similar to ListComponent, but 
  * the deep sky objects are stored in four separate QLists.
  * @author Thomas Kabelmann
  * @version 0.1
  */
-class DeepSkyComponent : public SkyComponent
+class DeepSkyComponent: public SkyComponent
 {
-#ifdef KSTARS_LITE
-    friend class DeepSkyItem;
-#endif
+public:
 
-  public:
-    explicit DeepSkyComponent(SkyComposite *);
+    DeepSkyComponent( SkyComposite* );
 
-    ~DeepSkyComponent() override;
+    ~DeepSkyComponent();
 
-    void draw(SkyPainter *skyp) override;
+    virtual void draw( SkyPainter *skyp );
 
-    /**
-     * @short draw all the labels in the prioritized LabelLists and then
+    /* @short draw all the labels in the prioritized LabelLists and then
      * clear the LabelLists.
      */
     void drawLabels();
@@ -70,55 +69,51 @@ class DeepSkyComponent : public SkyComponent
     /**
      * @short Update the sky positions of this component.  FIXME -jbb does nothing now
      *
-     * This function usually just updates the Horizontal (Azimuth/Altitude) coordinates of the
-     * objects in this component.  If the KSNumbers argument is not nullptr, this function also
-     * recomputes precession and nutation for the date in KSNumbers.
+     * This function usually just updates the Horizontal (Azimuth/Altitude)
+     * coordinates of the objects in this component.  If the KSNumbers* 
+     * argument is not NULL, this function also recomputes precession and
+     * nutation for the date in KSNumbers.
      * @p num Pointer to the KSNumbers object
-     * @note By default, the num parameter is nullptr, indicating that Precession/Nutation
-     * computation should be skipped; this computation is only occasionally required.
+     * @note By default, the num parameter is NULL, indicating that 
+     * Precession/Nutation computation should be skipped; this computation 
+     * is only occasionally required.
      */
-    void update(KSNumbers *num = nullptr) override;
+    virtual void update( KSNumbers *num=0 );
 
     /**
-     * @short Search the children of this SkyComponent for a SkyObject whose name matches the argument
+     * @short Search the children of this SkyComponent for 
+     * a SkyObject whose name matches the argument
      * @p name the name to be matched
-     * @return a pointer to the SkyObject whose name matches the argument, or a nullptr pointer
-     * if no match was found.
+     * @return a pointer to the SkyObject whose name matches
+     * the argument, or a NULL pointer if no match was found.
      */
-    SkyObject *findByName(const QString &name) override;
+    virtual SkyObject* findByName( const QString &name );
 
     /**
      * @short Searches the region(s) and appends the SkyObjects found to the list of sky objects
      *
-     * Look for a SkyObject that is in one of the regions
+     * Look for a SkyObject that is in one of the regions 
      * If found, then append to the list of sky objects
      * @p list list of SkyObject to which matching list has to be appended to
      * @p region defines the regions in which the search for SkyObject should be done within
      * @return void
      */
-    void objectsInArea(QList<SkyObject *> &list, const SkyRegion &region) override;
+    virtual void objectsInArea( QList<SkyObject*>& list, const SkyRegion& region );
 
-    SkyObject *objectNearest(SkyPoint *p, double &maxrad) override;
+    virtual SkyObject* objectNearest( SkyPoint *p, double &maxrad );
 
-    const QList<DeepSkyObject *> &objectList() const { return m_DeepSkyList; }
+    const QList<DeepSkyObject*>& objectList() const { return m_DeepSkyList; }
 
-    bool selected() override;
+    void clear();
 
-    /**
-     * @short Return the deep-sky limiting magnitude for the current zoom level
-     *
-     * The zoom level and various settings are determined by querying @class Options
-     * @note Also used by CatalogComponent::draw
-     */
-    static double determineDeepSkyMagnitudeLimit(void);
+    bool selected();
 
-
-  private:
+private:
     /**
      * @short Read the ngcic.dat deep-sky database.
      * Parse all lines from the deep-sky object catalog files. Construct a DeepSkyObject
      * from the data in each line, and add it to the DeepSkyComponent.
-     *
+     * 
      * Each line in the file is parsed according to column position:
      * @li 0        IC indicator [char]  If 'I' then IC object; if ' ' then NGC object
      * @li 1-4      Catalog number [int]  The NGC/IC catalog ID number
@@ -144,35 +139,41 @@ class DeepSkyComponent : public SkyComponent
      */
     void loadData();
 
-    void clearList(QList<DeepSkyObject *> &list);
+    void clearList(QList<DeepSkyObject*>& list);
 
     void mergeSplitFiles();
 
-    void drawDeepSkyCatalog(SkyPainter *skyp, bool drawObject, DeepSkyIndex *dsIndex, const QString &colorString,
-                            bool drawImage = false);
+    void drawDeepSkyCatalog( SkyPainter *skyp, bool drawObject, DeepSkyIndex* dsIndex,
+                             const QString& colorString, bool drawImage = false);
 
-    QList<DeepSkyObject *> m_DeepSkyList;
+    QList<DeepSkyObject*> m_DeepSkyList;
+    QList<DeepSkyObject*> m_MessierList;
+    QList<DeepSkyObject*> m_NGCList;
+    QList<DeepSkyObject*> m_ICList;
+    QList<DeepSkyObject*> m_OtherList;
 
-    QList<DeepSkyObject *> m_MessierList;
-    QList<DeepSkyObject *> m_NGCList;
-    QList<DeepSkyObject *> m_ICList;
-    QList<DeepSkyObject *> m_OtherList;
+    LabelList*     m_labelList[  MAX_LINENUMBER_MAG + 1 ];
+    bool           m_hideLabels;
+    double         m_zoomMagLimit;
 
-    LabelList *m_labelList[MAX_LINENUMBER_MAG + 1];
-    bool m_hideLabels { false };
-    double m_zoomMagLimit { 0 };
 
-    SkyMesh *m_skyMesh { nullptr };
+    SkyMesh* m_skyMesh;
     DeepSkyIndex m_DeepSkyIndex;
     DeepSkyIndex m_MessierIndex;
     DeepSkyIndex m_NGCIndex;
     DeepSkyIndex m_ICIndex;
     DeepSkyIndex m_OtherIndex;
 
-    void appendIndex(DeepSkyObject *o, DeepSkyIndex *dsIndex, Trixel trixel);
+    void appendIndex( DeepSkyObject *o, DeepSkyIndex* dsIndex, Trixel trixel );
 
-    QHash<QString, DeepSkyObject *> nameHash;
+    QHash<QString, DeepSkyObject*> nameHash;
+
+    /**
+     *@short adds a label to the lists of labels to be drawn prioritized
+     *by magnitude.
+     */
+    void addLabel( const QPointF& p, DeepSkyObject *obj );
 
-    /** @short adds a label to the lists of labels to be drawn prioritized by magnitude. */
-    void addLabel(const QPointF &p, DeepSkyObject *obj);
 };
+
+#endif
